# Transpiler Mate

A small and light yet powerful Python API + CLI to extract [Schema.org/SoftwareApplication](https://schema.org/SoftwareApplication) Metadata from an annotated [CWL](https://www.commonwl.org/) document and:

* transpile it to the [CodeMeta](https://codemeta.github.io/index.html) format;
* transpile it to the [DataCite Metadata](https://inveniordm.docs.cern.ch/reference/metadata/#metadata) properties;
* transpile it to [OGC API - Records](https://ogcapi.ogc.org/records/);
* transpile & publish a Record on [Invenio RDM](https://inveniosoftware.org/products/rdm/).

Read the documentation on: https://terradue.github.io/transpiler-mate/
